# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetTrustedOriginsResult',
    'AwaitableGetTrustedOriginsResult',
    'get_trusted_origins',
    'get_trusted_origins_output',
]

@pulumi.output_type
class GetTrustedOriginsResult:
    """
    A collection of values returned by getTrustedOrigins.
    """
    def __init__(__self__, filter=None, id=None, trusted_origins=None):
        if filter and not isinstance(filter, str):
            raise TypeError("Expected argument 'filter' to be a str")
        pulumi.set(__self__, "filter", filter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if trusted_origins and not isinstance(trusted_origins, list):
            raise TypeError("Expected argument 'trusted_origins' to be a list")
        pulumi.set(__self__, "trusted_origins", trusted_origins)

    @property
    @pulumi.getter
    def filter(self) -> Optional[builtins.str]:
        """
        Filter criteria. Filter value will be URL-encoded by the provider
        """
        return pulumi.get(self, "filter")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="trustedOrigins")
    def trusted_origins(self) -> Sequence['outputs.GetTrustedOriginsTrustedOriginResult']:
        return pulumi.get(self, "trusted_origins")


class AwaitableGetTrustedOriginsResult(GetTrustedOriginsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTrustedOriginsResult(
            filter=self.filter,
            id=self.id,
            trusted_origins=self.trusted_origins)


def get_trusted_origins(filter: Optional[builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTrustedOriginsResult:
    """
    Get List of Trusted Origins using filters.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    all = okta.get_trusted_origins()
    ```


    :param builtins.str filter: Filter criteria. Filter value will be URL-encoded by the provider
    """
    __args__ = dict()
    __args__['filter'] = filter
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getTrustedOrigins:getTrustedOrigins', __args__, opts=opts, typ=GetTrustedOriginsResult).value

    return AwaitableGetTrustedOriginsResult(
        filter=pulumi.get(__ret__, 'filter'),
        id=pulumi.get(__ret__, 'id'),
        trusted_origins=pulumi.get(__ret__, 'trusted_origins'))
def get_trusted_origins_output(filter: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTrustedOriginsResult]:
    """
    Get List of Trusted Origins using filters.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    all = okta.get_trusted_origins()
    ```


    :param builtins.str filter: Filter criteria. Filter value will be URL-encoded by the provider
    """
    __args__ = dict()
    __args__['filter'] = filter
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getTrustedOrigins:getTrustedOrigins', __args__, opts=opts, typ=GetTrustedOriginsResult)
    return __ret__.apply(lambda __response__: GetTrustedOriginsResult(
        filter=pulumi.get(__response__, 'filter'),
        id=pulumi.get(__response__, 'id'),
        trusted_origins=pulumi.get(__response__, 'trusted_origins')))
