# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'MappingMappingArgs',
    'MappingMappingArgsDict',
]

MYPY = False

if not MYPY:
    class MappingMappingArgsDict(TypedDict):
        expression: pulumi.Input[builtins.str]
        id: pulumi.Input[builtins.str]
        """
        The mapping property key.
        """
        push_status: NotRequired[pulumi.Input[builtins.str]]
elif False:
    MappingMappingArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class MappingMappingArgs:
    def __init__(__self__, *,
                 expression: pulumi.Input[builtins.str],
                 id: pulumi.Input[builtins.str],
                 push_status: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] id: The mapping property key.
        """
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "id", id)
        if push_status is not None:
            pulumi.set(__self__, "push_status", push_status)

    @property
    @pulumi.getter
    def expression(self) -> pulumi.Input[builtins.str]:
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "expression", value)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[builtins.str]:
        """
        The mapping property key.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter(name="pushStatus")
    def push_status(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "push_status")

    @push_status.setter
    def push_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "push_status", value)


