# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

accessToken: Optional[str]
"""
Bearer token granting privileges to Okta API.
"""

apiToken: Optional[str]
"""
API Token granting privileges to Okta API.
"""

backoff: Optional[bool]
"""
Use exponential back off strategy for rate limits.
"""

baseUrl: Optional[str]
"""
The Okta url. (Use 'oktapreview.com' for Okta testing)
"""

clientId: Optional[str]
"""
API Token granting privileges to Okta API.
"""

httpProxy: Optional[str]
"""
Alternate HTTP proxy of scheme://hostname or scheme://hostname:port format
"""

logLevel: Optional[int]
"""
providers log level. Minimum is 1 (TRACE), and maximum is 5 (ERROR)
"""

maxApiCapacity: Optional[int]
"""
Sets what percentage of capacity the provider can use of the total rate limit capacity while making calls to the Okta
management API endpoints. Okta API operates in one minute buckets. See Okta Management API Rate Limits:
https://developer.okta.com/docs/reference/rl-global-mgmt/
"""

maxRetries: Optional[int]
"""
maximum number of retries to attempt before erroring out.
"""

maxWaitSeconds: Optional[int]
"""
maximum seconds to wait when rate limit is hit. We use exponential backoffs when backoff is enabled.
"""

minWaitSeconds: Optional[int]
"""
minimum seconds to wait when rate limit is hit. We use exponential backoffs when backoff is enabled.
"""

orgName: Optional[str]
"""
The organization to manage in Okta.
"""

parallelism: Optional[int]
"""
Number of concurrent requests to make within a resource where bulk operations are not possible. Take note of
https://developer.okta.com/docs/api/getting_started/rate-limits.
"""

privateKey: Optional[str]
"""
API Token granting privileges to Okta API.
"""

privateKeyId: Optional[str]
"""
API Token Id granting privileges to Okta API.
"""

requestTimeout: Optional[int]
"""
Timeout for single request (in seconds) which is made to Okta, the default is `0` (means no limit is set). The maximum
value can be `300`.
"""

scopes: Optional[str]
"""
API Token granting privileges to Okta API.
"""

